#ifndef RND_DLG_PREF_WIN_H
#define RND_DLG_PREF_WIN_H

void rnd_dlg_pref_win_create(pref_ctx_t *ctx);

void rnd_dlg_pref_win_design_replaced(pref_ctx_t *ctx);

#endif
